import { useGetUserProfileQuery } from 'gql/generated/react';
import React, { FC } from 'react';
import { Base } from 'src/layouts/Base';
import { useRouter } from '@hooks/useRouter';
import { Skeleton, Stack } from '@mui/material';
import Container from '@mui/material/Container';
import { _404 } from '@components/404';
import Head from 'next/head';

export interface ProfileProps {}
export type ProfileType = FC<ProfileProps>;

export const Profile: ProfileType = () => {
    const router = useRouter();
    const id = router.query.id as string;

    const { data, error, loading } = useGetUserProfileQuery({
        variables: { id },
        skip: !id,
    });
    const user = data?.app_users_by_pk;

    if (loading) {
        return (
            <Base>
                <Skeleton variant={'rectangular'} />
            </Base>
        );
    }

    if (error) {
        return <_404 errorMessage={'User not found'} />;
    }

    // TODO: create user profile view
    return (
        <Base>
            <Head>
                <title>{user?.name ?? 'User'}&apos;s profile</title>
            </Head>

            <Container>
                <Stack direction={'column'}>
                    <h1>{user?.email}</h1>
                </Stack>
            </Container>
        </Base>
    );
};
