import * as React from 'react';
import AppBar from '@mui/material/AppBar';
import Toolbar from '@mui/material/Toolbar';
import Container from '@mui/material/Container';
import Avatar from '@mui/material/Avatar';
import Tooltip from '@mui/material/Tooltip';
import SearchIcon from '@mui/icons-material/Search';
import { theme_dark } from 'theme';
import InputBase from '@mui/material/InputBase';
import { Logo } from './Logo';
import { paths } from 'src/pages/pages';
import { useRouter } from '@hooks/useRouter';
import {
    DesktopNavMenuButton,
    MobileNavMenuButton,
} from '@components/common/Navbar/NavMenuButton';
import { styled } from '@mui/material';
import {
    DesktopNavMenuBox,
    MobileNavMenuBox,
} from '@components/common/Navbar/NavMenu';
import { HamburgerButton } from '@components/common/Navbar/HamburgerButton';
import { HamburgerMenu } from '@components/common/Navbar/HamburgerMenu';
import { UserHamburgerMenu } from '@components/common/Navbar/HamburgerMenu/UserHamburgerMenu';
import {
    UserMenuBox,
    UserMenuButton,
} from '@components/common/Navbar/UserMenu';
import { DesktopMenuButton, MobileMenuButton } from '../MenuButton';

// const router = useRouter();
// const Search =
// styled('div')`
//     position: 'relative';
//     border-radius: '10px';
//     background-color: 'rgba(255,255,255,0.15)';
//     &:hover {
//         background-color: 'rgba(255,255,255,0.25)';
//     }
//     margin-right: '25px';
//     width: '25%';
// `;

// const StyledInputBase =
//  styled(InputBase)`
//     color: 'inherit';
//     & .muiinputbase-input {
//         width: '10%';
//     }
// `;

// const SearchIconWrapper =
//  styled.div`
//     height: '100%';
//     position: 'absolute';
//     pointer-events: 'none';
//     display: 'flex';
//     align-items: 'center';
//     justify-content: 'center';
// `;

const StickyAppBar = styled(AppBar)`
    position: sticky;
    background-image: ${theme_dark.colors.primary};
`;

const ResponsiveAppBar = () => {
    const [anchorElNav, setAnchorElNav] = React.useState<null | HTMLElement>(
        null
    );
    const [anchorElUser, setAnchorElUser] = React.useState<null | HTMLElement>(
        null
    );

    const handleOpenNavMenu = (event: React.MouseEvent<HTMLElement>) => {
        setAnchorElNav(event.currentTarget);
    };
    const handleOpenUserMenu = (event: React.MouseEvent<HTMLElement>) => {
        setAnchorElUser(event.currentTarget);
    };

    const handleCloseNavMenu = () => {
        setAnchorElNav(null);
    };

    const handleCloseUserMenu = () => {
        setAnchorElUser(null);
    };

    return (
        <StickyAppBar>
            <Container maxWidth="xl">
                <Toolbar disableGutters>
                    <Logo />
                    <MobileNavMenuBox>
                        <HamburgerButton onClick={handleOpenNavMenu} />
                        <HamburgerMenu
                            anchorEl={anchorElNav}
                            onClose={handleCloseNavMenu}
                        >
                            {Object.entries(paths).map(
                                ([pageName, pagePath]) => (
                                    <MobileMenuButton
                                        text={pageName}
                                        path={pagePath}
                                        onClick={handleCloseNavMenu}
                                    />
                                )
                            )}
                        </HamburgerMenu>
                    </MobileNavMenuBox>
                    <DesktopNavMenuBox>
                        {Object.entries(paths).map(([pageName, pagePath]) => (
                            <DesktopMenuButton
                                text={pageName}
                                path={pagePath}
                            />
                        ))}
                    </DesktopNavMenuBox>
                    {/* <Search>
                        <SearchIconWrapper> 
                            <SearchIcon />
                        </SearchIconWrapper>
                        <StyledInputBase
                            placeholder="Search…"
                            inputProps={{ 'aria-label': 'search' }}
                        />
                    </Search> */}
                    <UserMenuBox>
                        <Tooltip title="Open settings">
                            <UserMenuButton onClick={handleOpenUserMenu} />
                        </Tooltip>
                        <UserHamburgerMenu
                            anchorEl={anchorElUser}
                            onClose={handleCloseUserMenu}
                        />
                    </UserMenuBox>
                </Toolbar>
            </Container>
        </StickyAppBar>
    );
};
export default ResponsiveAppBar;
